@@ -1,3 +1,5 @@
 # This variable is updated per tag as part of the CI process
 
-__version__ ="0.0.0.1",
\ No newline at end of file
+__version__ ="0.0.0.3"
+
+from .report import Report
